@@ -1,7 +1,7 @@
 import warnings
 
 from django.contrib.postgres.fields import ArrayField
-from django.db.models import Aggregate, BooleanField, JSONField, Value
+from django.db.models import Aggregate, BooleanField, JSONField, TextField, Value
 from django.utils.deprecation import RemovedInDjango50Warning
 
 from .mixins import OrderableAggMixin
@@ -10,6 +10,7 @@ __all__ = [
     "ArrayAgg",
     "BitAnd",
     "BitOr",
+    "BitXor",
     "BoolAnd",
     "BoolOr",
     "JSONBAgg",
@@ -64,6 +65,10 @@ class BitOr(Aggregate):
     function = "BIT_OR"
 
 
+class BitXor(Aggregate):
+    function = "BIT_XOR"
+
+
 class BoolAnd(Aggregate):
     function = "BOOL_AND"
     output_field = BooleanField()
@@ -94,6 +99,7 @@ class StringAgg(DeprecatedConvertValueMixin, OrderableAggMixin, Aggregate):
     function = "STRING_AGG"
     template = "%(function)s(%(distinct)s%(expressions)s %(ordering)s)"
     allow_distinct = True
+    output_field = TextField()
 
     # RemovedInDjango50Warning
     deprecation_value = ""
