@@ -212,7 +212,7 @@ class NonAggregateAnnotationTestCase(TestCase):
         with register_lookup(DecimalField, Floor):
             books = Book.objects.annotate(floor_price=F("price__floor"))
 
-        self.assertSequenceEqual(
+        self.assertCountEqual(
             books.values_list("pk", "floor_price"),
             [
                 (self.b1.pk, 30),
@@ -275,6 +275,26 @@ class NonAggregateAnnotationTestCase(TestCase):
         self.assertEqual(len(books), Book.objects.count())
         self.assertTrue(all(not book.selected for book in books))
 
+    def test_full_expression_annotation(self):
+        books = Book.objects.annotate(
+            selected=ExpressionWrapper(~Q(pk__in=[]), output_field=BooleanField()),
+        )
+        self.assertEqual(len(books), Book.objects.count())
+        self.assertTrue(all(book.selected for book in books))
+
+    def test_full_expression_annotation_with_aggregation(self):
+        qs = Book.objects.filter(isbn="159059725").annotate(
+            selected=ExpressionWrapper(~Q(pk__in=[]), output_field=BooleanField()),
+            rating_count=Count("rating"),
+        )
+        self.assertEqual([book.rating_count for book in qs], [1])
+
+    def test_aggregate_over_full_expression_annotation(self):
+        qs = Book.objects.annotate(
+            selected=ExpressionWrapper(~Q(pk__in=[]), output_field=BooleanField()),
+        ).aggregate(Sum("selected"))
+        self.assertEqual(qs["selected__sum"], Book.objects.count())
+
     def test_empty_queryset_annotation(self):
         qs = Author.objects.annotate(empty=Subquery(Author.objects.values("id").none()))
         self.assertIsNone(qs.first().empty)
@@ -466,6 +486,7 @@ class NonAggregateAnnotationTestCase(TestCase):
         book2 = Book.objects.annotate(adjusted_rating=None + F("rating")).get(
             pk=self.b1.pk
         )
+        self.assertIs(book1.adjusted_rating, None)
         self.assertEqual(book1.adjusted_rating, book2.adjusted_rating)
 
     def test_update_with_annotation(self):
