@@ -75,7 +75,7 @@ class YearTransform(models.Transform):
 
     def as_sql(self, compiler, connection):
         lhs_sql, params = compiler.compile(self.lhs)
-        return connection.ops.date_extract_sql("year", lhs_sql), params
+        return connection.ops.date_extract_sql("year", lhs_sql, params)
 
     @property
     def output_field(self):
@@ -323,6 +323,8 @@ class LookupTests(TestCase):
         with register_lookup(models.ForeignObject, Exactly):
             # getting the lookups again should re-cache
             self.assertIn("exactly", field.get_lookups())
+        # Unregistration should bust the cache.
+        self.assertNotIn("exactly", field.get_lookups())
 
 
 class BilateralTransformTests(TestCase):
