@@ -40,6 +40,14 @@ class ConnectionHandlerTests(SimpleTestCase):
         with self.assertRaisesMessage(ImproperlyConfigured, msg):
             conns["other"].ensure_connection()
 
+    def test_databases_property(self):
+        # The "databases" property is maintained for backwards compatibility
+        # with 3rd party packages. It should be an alias of the "settings"
+        # property.
+        conn = ConnectionHandler({})
+        self.assertNotEqual(conn.settings, {})
+        self.assertEqual(conn.settings, conn.databases)
+
     def test_nonexistent_alias(self):
         msg = "The connection 'nonexistent' doesn't exist."
         conns = ConnectionHandler(
@@ -50,26 +58,6 @@ class ConnectionHandlerTests(SimpleTestCase):
         with self.assertRaisesMessage(ConnectionDoesNotExist, msg):
             conns["nonexistent"]
 
-    def test_ensure_defaults_nonexistent_alias(self):
-        msg = "The connection 'nonexistent' doesn't exist."
-        conns = ConnectionHandler(
-            {
-                DEFAULT_DB_ALIAS: {"ENGINE": "django.db.backends.dummy"},
-            }
-        )
-        with self.assertRaisesMessage(ConnectionDoesNotExist, msg):
-            conns.ensure_defaults("nonexistent")
-
-    def test_prepare_test_settings_nonexistent_alias(self):
-        msg = "The connection 'nonexistent' doesn't exist."
-        conns = ConnectionHandler(
-            {
-                DEFAULT_DB_ALIAS: {"ENGINE": "django.db.backends.dummy"},
-            }
-        )
-        with self.assertRaisesMessage(ConnectionDoesNotExist, msg):
-            conns.prepare_test_settings("nonexistent")
-
 
 class DatabaseErrorWrapperTests(TestCase):
     @unittest.skipUnless(connection.vendor == "postgresql", "PostgreSQL test")
