@@ -342,6 +342,34 @@ class FileUploadTests(TestCase):
         for i, name in enumerate(filenames):
             self.assertIsNone(received.get("file%s" % i))
 
+    def test_non_printable_chars_in_file_names(self):
+        file_name = "non-\x00printable\x00\n_chars.txt\x00"
+        payload = client.FakePayload()
+        payload.write(
+            "\r\n".join(
+                [
+                    "--" + client.BOUNDARY,
+                    f'Content-Disposition: form-data; name="file"; '
+                    f'filename="{file_name}"',
+                    "Content-Type: application/octet-stream",
+                    "",
+                    "You got pwnd.\r\n",
+                ]
+            )
+        )
+        payload.write("\r\n--" + client.BOUNDARY + "--\r\n")
+        r = {
+            "CONTENT_LENGTH": len(payload),
+            "CONTENT_TYPE": client.MULTIPART_CONTENT,
+            "PATH_INFO": "/echo/",
+            "REQUEST_METHOD": "POST",
+            "wsgi.input": payload,
+        }
+        response = self.client.request(**r)
+        # Non-printable chars are sanitized.
+        received = response.json()
+        self.assertEqual(received["file"], "non-printable_chars.txt")
+
     def test_dangerous_file_names(self):
         """Uploaded file names should be sanitized before ever reaching the view."""
         # This test simulates possible directory traversal attacks by a
@@ -916,3 +944,9 @@ class MultiParserTests(SimpleTestCase):
         for raw_line, expected_title in test_data:
             parsed = parse_header(raw_line)
             self.assertEqual(parsed[1]["title"], expected_title)
+
+    def test_parse_header_with_double_quotes_and_semicolon(self):
+        self.assertEqual(
+            parse_header(b'form-data; name="files"; filename="fo\\"o;bar"'),
+            ("form-data", {"name": b"files", "filename": b'fo"o;bar'}),
+        )
