@@ -5,7 +5,6 @@ from django.db import models
 from django.forms import CharField, FileField, Form, ModelForm
 from django.forms.models import ModelFormMetaclass
 from django.test import SimpleTestCase, TestCase
-from tests.forms_tests.tests import jinja2_tests
 
 from ..models import (
     BoundaryModel,
@@ -16,6 +15,7 @@ from ..models import (
     FileModel,
     OptionalMultiChoiceModel,
 )
+from . import jinja2_tests
 
 
 class ChoiceFieldForm(ModelForm):
