@@ -1212,7 +1212,9 @@ class LookupTests(TestCase):
 
     def test_exact_exists(self):
         qs = Article.objects.filter(pk=OuterRef("pk"))
-        seasons = Season.objects.annotate(pk_exists=Exists(qs),).filter(
+        seasons = Season.objects.annotate(
+            pk_exists=Exists(qs),
+        ).filter(
             pk_exists=Exists(qs),
         )
         self.assertCountEqual(seasons, Season.objects.all())
