@@ -7,7 +7,7 @@ from django.dispatch import receiver
 from django.test import SimpleTestCase, TestCase
 from django.test.utils import isolate_apps
 
-from .models import Author, Book, Car, Person
+from .models import Author, Book, Car, Page, Person
 
 
 class BaseSignalSetup:
@@ -136,16 +136,16 @@ class SignalTests(BaseSignalSetup, TestCase):
     def test_delete_signals(self):
         data = []
 
-        def pre_delete_handler(signal, sender, instance, **kwargs):
-            data.append((instance, sender, instance.id is None))
+        def pre_delete_handler(signal, sender, instance, origin, **kwargs):
+            data.append((instance, sender, instance.id is None, origin))
 
         # #8285: signals can be any callable
         class PostDeleteHandler:
             def __init__(self, data):
                 self.data = data
 
-            def __call__(self, signal, sender, instance, **kwargs):
-                self.data.append((instance, sender, instance.id is None))
+            def __call__(self, signal, sender, instance, origin, **kwargs):
+                self.data.append((instance, sender, instance.id is None, origin))
 
         post_delete_handler = PostDeleteHandler(data)
 
@@ -157,8 +157,8 @@ class SignalTests(BaseSignalSetup, TestCase):
             self.assertEqual(
                 data,
                 [
-                    (p1, Person, False),
-                    (p1, Person, False),
+                    (p1, Person, False, p1),
+                    (p1, Person, False, p1),
                 ],
             )
             data[:] = []
@@ -172,8 +172,8 @@ class SignalTests(BaseSignalSetup, TestCase):
             self.assertEqual(
                 data,
                 [
-                    (p2, Person, False),
-                    (p2, Person, False),
+                    (p2, Person, False, p2),
+                    (p2, Person, False, p2),
                 ],
             )
             data[:] = []
@@ -189,6 +189,84 @@ class SignalTests(BaseSignalSetup, TestCase):
             signals.pre_delete.disconnect(pre_delete_handler)
             signals.post_delete.disconnect(post_delete_handler)
 
+    def test_delete_signals_origin_model(self):
+        data = []
+
+        def pre_delete_handler(signal, sender, instance, origin, **kwargs):
+            data.append((sender, origin))
+
+        def post_delete_handler(signal, sender, instance, origin, **kwargs):
+            data.append((sender, origin))
+
+        person = Person.objects.create(first_name="John", last_name="Smith")
+        book = Book.objects.create(name="Rayuela")
+        Page.objects.create(text="Page 1", book=book)
+        Page.objects.create(text="Page 2", book=book)
+
+        signals.pre_delete.connect(pre_delete_handler, weak=False)
+        signals.post_delete.connect(post_delete_handler, weak=False)
+        try:
+            # Instance deletion.
+            person.delete()
+            self.assertEqual(data, [(Person, person), (Person, person)])
+            data[:] = []
+            # Cascade deletion.
+            book.delete()
+            self.assertEqual(
+                data,
+                [
+                    (Page, book),
+                    (Page, book),
+                    (Book, book),
+                    (Page, book),
+                    (Page, book),
+                    (Book, book),
+                ],
+            )
+        finally:
+            signals.pre_delete.disconnect(pre_delete_handler)
+            signals.post_delete.disconnect(post_delete_handler)
+
+    def test_delete_signals_origin_queryset(self):
+        data = []
+
+        def pre_delete_handler(signal, sender, instance, origin, **kwargs):
+            data.append((sender, origin))
+
+        def post_delete_handler(signal, sender, instance, origin, **kwargs):
+            data.append((sender, origin))
+
+        Person.objects.create(first_name="John", last_name="Smith")
+        book = Book.objects.create(name="Rayuela")
+        Page.objects.create(text="Page 1", book=book)
+        Page.objects.create(text="Page 2", book=book)
+
+        signals.pre_delete.connect(pre_delete_handler, weak=False)
+        signals.post_delete.connect(post_delete_handler, weak=False)
+        try:
+            # Queryset deletion.
+            qs = Person.objects.all()
+            qs.delete()
+            self.assertEqual(data, [(Person, qs), (Person, qs)])
+            data[:] = []
+            # Cascade deletion.
+            qs = Book.objects.all()
+            qs.delete()
+            self.assertEqual(
+                data,
+                [
+                    (Page, qs),
+                    (Page, qs),
+                    (Book, qs),
+                    (Page, qs),
+                    (Page, qs),
+                    (Book, qs),
+                ],
+            )
+        finally:
+            signals.pre_delete.disconnect(pre_delete_handler)
+            signals.post_delete.disconnect(post_delete_handler)
+
     def test_decorators(self):
         data = []
 
