@@ -17,6 +17,7 @@ from django.core.validators import (
     MinValueValidator,
     ProhibitNullCharactersValidator,
     RegexValidator,
+    StepValueValidator,
     URLValidator,
     int_list_validator,
     validate_comma_separated_integer_list,
@@ -29,8 +30,7 @@ from django.core.validators import (
     validate_slug,
     validate_unicode_slug,
 )
-from django.test import SimpleTestCase, ignore_warnings
-from django.utils.deprecation import RemovedInDjango41Warning
+from django.test import SimpleTestCase
 
 try:
     from PIL import Image  # noqa
@@ -441,12 +441,21 @@ TEST_DATA = [
     # limit_value may be a callable.
     (MinValueValidator(lambda: 1), 0, ValidationError),
     (MinValueValidator(lambda: 1), 1, None),
+    (StepValueValidator(3), 0, None),
     (MaxLengthValidator(10), "", None),
     (MaxLengthValidator(10), 10 * "x", None),
     (MaxLengthValidator(10), 15 * "x", ValidationError),
     (MinLengthValidator(10), 15 * "x", None),
     (MinLengthValidator(10), 10 * "x", None),
     (MinLengthValidator(10), "", ValidationError),
+    (StepValueValidator(3), 1, ValidationError),
+    (StepValueValidator(3), 8, ValidationError),
+    (StepValueValidator(3), 9, None),
+    (StepValueValidator(0.001), 0.55, None),
+    (StepValueValidator(0.001), 0.5555, ValidationError),
+    (StepValueValidator(Decimal(0.02)), 0.88, None),
+    (StepValueValidator(Decimal(0.02)), Decimal(0.88), None),
+    (StepValueValidator(Decimal(0.02)), Decimal(0.77), ValidationError),
     (URLValidator(EXTENDED_SCHEMES), "file://localhost/path", None),
     (URLValidator(EXTENDED_SCHEMES), "git://example.com/", None),
     (
@@ -716,6 +725,10 @@ class TestValidatorEquality(TestCase):
             MaxValueValidator(44),
         )
         self.assertEqual(MaxValueValidator(44), mock.ANY)
+        self.assertEqual(
+            StepValueValidator(0.003),
+            StepValueValidator(0.003),
+        )
         self.assertNotEqual(
             MaxValueValidator(44),
             MinValueValidator(44),
@@ -724,6 +737,10 @@ class TestValidatorEquality(TestCase):
             MinValueValidator(45),
             MinValueValidator(11),
         )
+        self.assertNotEqual(
+            StepValueValidator(3),
+            StepValueValidator(2),
+        )
 
     def test_decimal_equality(self):
         self.assertEqual(
@@ -790,42 +807,3 @@ class TestValidatorEquality(TestCase):
             ProhibitNullCharactersValidator(message="message", code="code1"),
             ProhibitNullCharactersValidator(message="message", code="code2"),
         )
-
-
-class DeprecationTests(SimpleTestCase):
-    @ignore_warnings(category=RemovedInDjango41Warning)
-    def test_whitelist(self):
-        validator = EmailValidator(whitelist=["localdomain"])
-        self.assertEqual(validator.domain_allowlist, ["localdomain"])
-        self.assertIsNone(validator("email@localdomain"))
-        self.assertEqual(validator.domain_allowlist, validator.domain_whitelist)
-
-    def test_whitelist_warning(self):
-        msg = "The whitelist argument is deprecated in favor of allowlist."
-        with self.assertRaisesMessage(RemovedInDjango41Warning, msg):
-            EmailValidator(whitelist="localdomain")
-
-    @ignore_warnings(category=RemovedInDjango41Warning)
-    def test_domain_whitelist(self):
-        validator = EmailValidator()
-        validator.domain_whitelist = ["mydomain"]
-        self.assertEqual(validator.domain_allowlist, ["mydomain"])
-        self.assertEqual(validator.domain_allowlist, validator.domain_whitelist)
-
-    def test_domain_whitelist_access_warning(self):
-        validator = EmailValidator()
-        msg = (
-            "The domain_whitelist attribute is deprecated in favor of "
-            "domain_allowlist."
-        )
-        with self.assertRaisesMessage(RemovedInDjango41Warning, msg):
-            validator.domain_whitelist
-
-    def test_domain_whitelist_set_warning(self):
-        validator = EmailValidator()
-        msg = (
-            "The domain_whitelist attribute is deprecated in favor of "
-            "domain_allowlist."
-        )
-        with self.assertRaisesMessage(RemovedInDjango41Warning, msg):
-            validator.domain_whitelist = ["mydomain"]
